==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/tr.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "%s kişisel işlem akışı",
    "Your feed URL is invalid" : "Akış adresiniz geçersiz",
    "Activity feed for %1$s" : "%1$s için işlem akışı",
    "Activity feed" : "İşlem akışı",
    "Your settings have been updated." : "Ayarlarınız güncellendi.",
    "Settings have been updated." : "Ayarlar güncellendi",
    "Recent activity" : "Son işlemler",
    "No activities" : "Herhangi bir işlem yok",
    "More activities" : "Diğer işlemler",
    "Daily activity summary for %s" : "%s için günlük işlem özeti",
    "_and %n more…_::_and %n more…_" : ["ve %n diğer...","ve %n diğer..."],
    "All activities" : "Tüm işlemler",
    "By others" : "Diğerleri tarafından",
    "By you" : "Sizin tarafınızdan",
    "Activity at %s" : "%s sunucusundaki işlemler",
    "Hello %s" : "Merhaba %s",
    "Hello %s," : "Merhaba %s,",
    "There was some activity at %s" : "%s üzerinde bazı işlemler yapıldı",
    "_and %n more _::_and %n more _" : ["ve %n diğer","ve %n diğer"],
    "Mail" : "E-posta",
    "Push" : "Anında",
    "Activity" : "İşlem",
    "Notifications" : "Bildirimler",
    "This application enables people to view a log of activities about them, their files or other data." : "Bu uygulama, kişilerin dosyaları ve diğer verileri üzerinde yapılan işlemlerin günlük kaydını görebilmesini sağlar.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Bu uygulama, kişilerin Nextcloud üzerindeki dosyaları ve verileriyle ilgili işlemleri görmelerini sağlar.\n\t\tHer kişi kişisel ayarlarından, hangi işlemin cep telefonu iletisi olarak,\n\t\te-posta iletisi olarak ya da her sabah günlük özet olarak gönderileceğini\n\t\tseçerek yapılandırabilir.\n\t\tAyrıntılı bilgi almak için işlem belgelerine bakabilirsiniz.",
    "Send email" : "E-posta gönder",
    "Send push notification" : "Anında bildirim gönder",
    "Activity notification configuration" : "İşlem bildirimi yapılandırması",
    "Today" : "Bugün",
    "Yesterday" : "Dün",
    "You need to set up your email address before you can receive notification emails." : "Bildirim e-postalarını alabilmek için e-posta adresinizi belirtmelisiniz.",
    "Send activity emails" : "İşlem e-postaları gönderilsin",
    "As soon as possible" : "Olabildiğince çabuk",
    "Hourly" : "Saatlik",
    "Daily" : "Günlük",
    "Weekly" : "Haftalık",
    "You commented" : "Yorum yaptınız",
    "Message deleted by author" : "İleti yazarı tarafından silindi",
    "Open {filename}" : "{filename} aç",
    "in {path}" : "{path} içinde",
    "Home" : "Giriş",
    "Could not load activities" : "İşlemler yüklenemedi",
    "Loading activities" : "İşlemler yükleniyor",
    "This stream will show events like additions, changes & shares" : "Bu akışta ekleme, değiştirme ve paylaşım gibi olaylar görüntülenir",
    "No activity yet" : "Henüz bir işlem yok",
    "Loading more activities" : "Diğer işlemler yükleniyor",
    "No more activities." : "Başka bir işlem yok.",
    "Could not enable RSS link" : "RSS bağlantısı kullanıma alınamadı",
    "RSS link copied to clipboard" : "RSS bağlantısı panoya kopyalandı",
    "Could not copy the RSS link, please copy manually:" : "RSS bağlantısı panoya kopyalanamadı. Lütfen el ile kopyalayın:",
    "Activity settings" : "İşlem ayarları",
    "Enable RSS feed" : "RSS akışı kullanılsın",
    "RSS feed" : "RSS akışı",
    "Copy RSS feed link" : "RSS akışı bağlantısını kopyala",
    "Personal notification settings" : "Kişisel bildirim ayarları",
    "Unable to load the activity list" : "İşlem listesi yüklenemedi",
    "Choose for which activities you want to get an email or push notification." : "E-posta ya da anında bildirim almak istediğiniz işlemleri seçin.",
    "Choose for which activities you want to get a push notification." : "Anında bildirim almak istediğiniz işlemleri seçin.",
    "Notification" : "Bildirimler",
    "Enable notification emails" : "Bildirim e-postaları kullanılsın",
    "Daily activity summary" : "Günlük işlem özeti",
    "Send daily activity summary in the morning" : "Her sabah günlük işlem özeti gönderilsin",
    "Default settings" : "Varsayılan ayarlar",
    "Configure the default notification settings for new accounts." : "Yeni hesaplar için varsayılan bildirim ayarlarını yapılandırın.",
    "Unable to save the settings" : "Ayarlar kaydedilemedi",
    "No more events to load" : "Yüklenecek başka bir olay yok"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/activity/l10n/tr.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "%s kişisel işlem akışı",
    "Your feed URL is invalid" : "Akış adresiniz geçersiz",
    "Activity feed for %1$s" : "%1$s için işlem akışı",
    "Activity feed" : "İşlem akışı",
    "Your settings have been updated." : "Ayarlarınız güncellendi.",
    "Settings have been updated." : "Ayarlar güncellendi",
    "remote user" : "uzak kullanıcı",
    "Recent activity" : "Son işlemler",
    "No activities" : "Herhangi bir işlem yok",
    "More activities" : "Diğer işlemler",
    "Daily activity summary for %s" : "%s için günlük işlem özeti",
    "_and %n more…_::_and %n more…_" : ["ve %n diğer...","ve %n diğer..."],
    "You can disable daily digest emails in the <a href=\"%s\">settings</a>." : "<a href=\"%s\">Ayarlar bölümünden</a> günlük özet e-postalarını kullanımdan kaldırabilirsiniz.",
    "You can disable daily digest emails in the settings: %s" : "Ayarlar bölümünden günlük özet e-postalarını kullanımdan kaldırabilirsiniz: %s",
    "All activities" : "Tüm işlemler",
    "By others" : "Diğerleri tarafından",
    "By you" : "Sizin tarafınızdan",
    "Activity at %s" : "%s sunucusundaki işlemler",
    "Hello %s" : "Merhaba %s",
    "Hello %s," : "Merhaba %s,",
    "There was some activity at %s" : "%s üzerinde bazı işlemler yapıldı",
    "_and %n more _::_and %n more _" : ["ve %n diğer","ve %n diğer"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "<a href=\"%s\">Ayarlar bölümünden</a> bu e-postaların sıklığını değiştirebilir veya kullanımdan kaldırabilirsiniz.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Ayarlar bölümünden bu e-postaların sıklığını değiştirebilir veya kullanımdan kaldırabilirsiniz: %s",
    "Mail" : "E-posta",
    "Push" : "Anında",
    "Activity" : "İşlem",
    "Notifications" : "Bildirimler",
    "This application enables people to view a log of activities about them, their files or other data." : "Bu uygulama, kişilerin dosyaları ve diğer verileri üzerinde yapılan işlemlerin günlük kaydını görebilmesini sağlar.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Bu uygulama, kişilerin Nextcloud üzerindeki dosyaları ve verileriyle ilgili işlemleri görmelerini sağlar.\n\t\tHer kişi kişisel ayarlarından, hangi işlemin cep telefonu iletisi olarak,\n\t\te-posta iletisi olarak ya da her sabah günlük özet olarak gönderileceğini\n\t\tseçerek yapılandırabilir.\n\t\tAyrıntılı bilgi almak için işlem belgelerine bakabilirsiniz.",
    "Send email" : "E-posta gönder",
    "Send push notification" : "Anında bildirim gönder",
    "Activity notification configuration" : "İşlem bildirimi yapılandırması",
    "Today" : "Bugün",
    "Yesterday" : "Dün",
    "You need to set up your email address before you can receive notification emails." : "Bildirim e-postalarını alabilmek için e-posta adresinizi belirtmelisiniz.",
    "Send activity emails" : "İşlem e-postaları gönderilsin",
    "As soon as possible" : "Olabildiğince çabuk",
    "Hourly" : "Saatlik",
    "Daily" : "Günlük",
    "Weekly" : "Haftalık",
    "You commented" : "Yorum yaptınız",
    "Message deleted by author" : "İleti yazarı tarafından silindi",
    "Open {filename}" : "{filename} aç",
    "in {path}" : "{path} içinde",
    "Home" : "Giriş",
    "Could not load activities" : "İşlemler yüklenemedi",
    "Loading activities" : "İşlemler yükleniyor",
    "This stream will show events like additions, changes & shares" : "Bu akışta ekleme, değiştirme ve paylaşma gibi olaylar görüntülenir",
    "No activity yet" : "Henüz bir işlem yok",
    "Loading more activities" : "Diğer işlemler yükleniyor",
    "No more activities." : "Başka bir işlem yok.",
    "Could not enable RSS link" : "RSS bağlantısı açılamadı",
    "RSS link copied to clipboard" : "RSS bağlantısı panoya kopyalandı",
    "Could not copy the RSS link, please copy manually:" : "RSS bağlantısı panoya kopyalanamadı. Lütfen el ile kopyalayın:",
    "Activity settings" : "İşlem ayarları",
    "Enable RSS feed" : "RSS akışı kullanılsın",
    "RSS feed" : "RSS akışı",
    "Copy RSS feed link" : "RSS akışı bağlantısını kopyala",
    "Personal notification settings" : "Kişisel bildirim ayarları",
    "Unable to load the activity list" : "İşlem listesi yüklenemedi",
    "Choose for which activities you want to get an email or push notification." : "E-posta ya da anında bildirim almak istediğiniz işlemleri seçin.",
    "Choose for which activities you want to get a push notification." : "Anında bildirim almak istediğiniz işlemleri seçin.",
    "Notification" : "Bildirimler",
    "Enable notification emails" : "Bildirim e-postaları kullanılsın",
    "Daily activity summary" : "Günlük işlem özeti",
    "Send daily activity summary in the morning" : "Her sabah günlük işlem özeti gönderilsin",
    "Default settings" : "Varsayılan ayarlar",
    "Configure the default notification settings for new accounts." : "Yeni hesaplar için varsayılan bildirim ayarlarını yapılandırın.",
    "Unable to save the settings" : "Ayarlar kaydedilemedi",
    "No more events to load" : "Yüklenecek başka bir olay yok"
},
"nplurals=2; plural=(n > 1);");
